"use strict";

exports.mkdir = mkdir;
exports.doesntExist = doesntExist;

var _fs = require('fs');

var fs = _fs;

var _mkdirp = require('mkdirp');

var mkdirp = _mkdirp;

/**
 * Promiseful version of mkdirp
 * @param  {string} path
 * @return {Promise}
 */

function mkdir(path) {
    return new Promise(function (resolve, reject) {
        mkdirp(path, function (err) {
            if (err) {
                reject(err);
            } else {
                resolve();
            }
        });
    });
}

/**
 * Passes if a directory doesn't exist.
 * @param  {string} path
 * @return {Promise}
 */

function doesntExist(path) {
    return new Promise(function (resolve, reject) {
        fs.stat(path, function (err, stats) {
            if (err) {
                resolve();
            } else {
                reject(stats);
            }
        });
    });
}