'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

var _chalk = require('chalk');

var chalk = _chalk;

var _prompt = require('prompt');

var prompt = _prompt;

var _logging = require('../logging');

var _underscore = require('underscore');

var _ = _underscore;

/**
 * Represents a single step in the installation process.
 */

var StepBase = (function () {

    /**
     * Public constructor
     *
     * Here the step should register any commandline options it needs with
     * commander.
     * @param  {Commander} globals
     */

    function StepBase(globals) {
        _classCallCheck(this, StepBase);

        this.globals = globals;

        // Logging functions
        this.success = _logging.success;
        this.failure = _logging.failure;
        this.details = _logging.details;
    }

    /**
     * Abort the installation
     * @param  {object|array<object>} message
     * @param  {number} [errorCode=1]
     */

    _createClass(StepBase, [{
        key: 'abort',
        value: function abort(message) {
            var errorCode = arguments.length <= 1 || arguments[1] === undefined ? 1 : arguments[1];

            if (!_.isArray(message)) {
                message = [message];
            }
            message.forEach(function (text) {
                if (!_.isString(text)) {
                    text = String(text);
                }

                if (text.length > 0) {
                    console.error(chalk.red(String(text)));
                }
            });
            process.exit(errorCode);
        }

        /**
         * Prompt the user for a yes/no answer.
         * @param  {string} message
         * @return {Promise<boolean>} true if yes, false otherwise
         */
    }, {
        key: 'yesNo',
        value: function yesNo(message) {
            if (this.globals.silent) {
                return Promise.resolve(false);
            } else {
                return new Promise(function (resolve) {
                    prompt.start();
                    prompt.get({
                        properties: {
                            overwrite: {
                                description: message + ' (y)es or (n)o',
                                required: true,
                                pattern: /[yn]/,
                                message: '(y)es or (n)o',
                                'default': 'n'
                            }
                        }
                    }, function (err, result) {
                        if (err || result.overwrite !== 'y') {
                            resolve(false);
                        }
                        resolve(true);
                    });
                });
            }
        }

        /**
         * Gets the name of the section
         * @return {string}
         */
    }, {
        key: 'tryRun',

        /**
         * Tries to run the step
         * @param  {object} previousStepResults - results from the previous step
         * @return {Promise|object} results
         */
        value: function tryRun(previousStepResults) {
            var _this = this;

            return Promise.resolve(this.shouldRun()).then(function (shouldRun) {
                if (shouldRun) {

                    // If a section title was specified, print that title.
                    if (_this.section && _this.section.length > 0) {
                        (0, _logging.section)(_this.section);
                    }

                    // Run the step.
                    return _this.run(previousStepResults);
                } else {
                    return previousStepResults;
                }
            });
        }

        /**
         * Checks if the step should run
         * @param  {object} previousStepResults - results from the previous step
         * @return {Promise|boolean} should run
         */
    }, {
        key: 'shouldRun',
        value: function shouldRun(previousStepResults) {
            return true;
        }

        /**
         * Run the step
         * @param  {object} previousStepResults - results from the previous step
         * @return {Promise|object} results
         */
    }, {
        key: 'run',
        value: function run(previousStepResults) {}
    }, {
        key: 'section',
        get: function get() {}
    }]);

    return StepBase;
})();

exports.StepBase = StepBase;